"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var mixins_1 = tslib_1.__importDefault(require("../utils/mixins"));
var FieldPropsMixin_1 = tslib_1.__importDefault(require("./FieldPropsMixin"));
var LoadingSlotMixin_1 = tslib_1.__importDefault(require("./LoadingSlotMixin"));
var BaseModel_1 = require("../models/BaseModel");
var ConfigHandler_1 = require("../utils/ConfigHandler");
/**
 * Main component to display label of a field
 */
exports.default = mixins_1.default(LoadingSlotMixin_1.default, FieldPropsMixin_1.default).extend({
    name: 'FieldLabel',
    inheritAttrs: false,
    props: {
        model: {
            default: null,
            validator: function (value) { return value === null || value instanceof BaseModel_1.BaseModel ||
                // Allow static BaseModel class
                Boolean(value && value.prototype instanceof BaseModel_1.BaseModel); }
        },
        tag: {
            type: String,
            default: 'span'
        }
    },
    data: function () { return ({
        label: null
    }); },
    asyncComputed: {
        label: function () {
            return tslib_1.__awaiter(this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    ConfigHandler_1.configHandler.checkWarningUseAsyncComputed();
                    return [2 /*return*/, this.resolveLabel()];
                });
            });
        }
    },
    watch: {
        fieldObj: function () {
            this.setResolveLabel();
        }
    },
    created: function () {
        this.setResolveLabel();
    },
    methods: {
        setResolveLabel: function () {
            return tslib_1.__awaiter(this, void 0, void 0, function () {
                var _a;
                return tslib_1.__generator(this, function (_b) {
                    switch (_b.label) {
                        case 0:
                            if (!!ConfigHandler_1.configHandler.useAsyncComputed()) return [3 /*break*/, 2];
                            _a = this;
                            return [4 /*yield*/, this.resolveLabel()];
                        case 1:
                            _a.label = _b.sent();
                            _b.label = 2;
                        case 2: return [2 /*return*/];
                    }
                });
            });
        },
        resolveLabel: function () {
            return tslib_1.__awaiter(this, void 0, void 0, function () {
                var field;
                return tslib_1.__generator(this, function (_a) {
                    if (this.fieldObj) {
                        field = this.fieldObj;
                        return [2 /*return*/, field.label];
                    }
                    else {
                        return [2 /*return*/, null];
                    }
                    return [2 /*return*/];
                });
            });
        },
        renderLabel: function (h) {
            if (this.$scopedSlots && this.$scopedSlots.default) {
                return h(this.tag, this.$scopedSlots.default({
                    label: this.label
                }));
            }
            else {
                return h(this.tag, this.label);
            }
        }
    },
    render: function (h) {
        if (this.label) {
            return this.renderLabel(h);
        }
        else {
            return this.renderLoading(h);
        }
    }
});
