"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DecimalField = void 0;
var tslib_1 = require("tslib");
var common_1 = require("../utils/common");
var FormatStringField_1 = require("./FormatStringField");
var DecimalField = /** @class */ (function (_super) {
    tslib_1.__extends(DecimalField, _super);
    function DecimalField() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Validate field options
     */
    DecimalField.prototype.validateOptions = function (options) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, _super.prototype.validateOptions.call(this, options)];
                    case 1:
                        options = (_a.sent());
                        if (!Number.isInteger(options.decimalPlaces)) {
                            console.error('[vue-service-model] Invalid options.decimalPlaces for DecimalField: ', options.decimalPlaces);
                            options.decimalPlaces = 0;
                        }
                        return [2 /*return*/, options];
                }
            });
        });
    };
    /**
     * Prepare data for input render
     */
    DecimalField.prototype.prepareInputRender = function (inputProps) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _a, value, options;
            return tslib_1.__generator(this, function (_b) {
                switch (_b.label) {
                    case 0: return [4 /*yield*/, Promise.all([
                            this.value,
                            this.options
                        ])];
                    case 1:
                        _a = _b.sent(), value = _a[0], options = _a[1];
                        return [2 /*return*/, {
                                value: value,
                                decimalPlaces: options.decimalPlaces,
                                inputProps: inputProps
                            }];
                }
            });
        });
    };
    DecimalField.prototype.inputRender = function (h, _a) {
        var _this = this;
        var value = _a.value, decimalPlaces = _a.decimalPlaces, inputProps = _a.inputProps;
        var disabled = inputProps.disabled, readonly = inputProps.readonly;
        var step = Math.pow(0.1, decimalPlaces).toPrecision(1);
        return h('input', {
            attrs: {
                type: 'number',
                value: value,
                step: step,
                disabled: disabled,
                readonly: readonly
            },
            on: {
                input: function (event) {
                    var target = event.target;
                    _this.setParseValue(target.value);
                }
            }
        });
    };
    /**
     * Parse value and convert to number or null
     */
    DecimalField.prototype.valueParser = function (rawValue) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, common_1.isNull(rawValue) ? null : parseFloat(rawValue)];
            });
        });
    };
    return DecimalField;
}(FormatStringField_1.FormatStringField));
exports.DecimalField = DecimalField;
