"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ForeignKeyField = void 0;
var tslib_1 = require("tslib");
var common_1 = require("../utils/common");
var RenderableField_1 = require("./RenderableField");
var ServiceModel_1 = require("../models/ServiceModel");
var FieldExceptions_1 = require("../exceptions/FieldExceptions");
var FormatStringField_1 = require("./FormatStringField");
var ForeignKeyField = /** @class */ (function (_super) {
    tslib_1.__extends(ForeignKeyField, _super);
    function ForeignKeyField() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * Return instance of relation model as value
     */
    ForeignKeyField.prototype.getValue = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var value, options, model;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, _super.prototype.getValue.call(this)];
                    case 1:
                        value = _a.sent();
                        if (common_1.isNull(value))
                            return [2 /*return*/, null];
                        return [4 /*yield*/, this.options];
                    case 2:
                        options = _a.sent();
                        model = options.model;
                        return [2 /*return*/, model.objects.detail(value)];
                }
            });
        });
    };
    /**
     * Validate field options
     */
    ForeignKeyField.prototype.validateOptions = function (options) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, _super.prototype.validateOptions.call(this, options)];
                    case 1:
                        options = (_a.sent());
                        if (!options.model) {
                            throw new FieldExceptions_1.RequiredFieldOptionsException(this, 'options.model');
                        }
                        if (!options.fieldName) {
                            throw new FieldExceptions_1.RequiredFieldOptionsException(this, 'options.fieldName');
                        }
                        if (!(options.model.prototype instanceof ServiceModel_1.ServiceModel)) {
                            throw new FieldExceptions_1.InvalidFieldOptionsException(this, 'options.model', 'Model does not inherit from ServiceModel');
                        }
                        return [2 /*return*/, options];
                }
            });
        });
    };
    /**
     * Retrieve field from relation model
     */
    ForeignKeyField.prototype.prepareDisplayRender = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var instance, options, _a;
            return tslib_1.__generator(this, function (_b) {
                switch (_b.label) {
                    case 0: return [4 /*yield*/, this.value];
                    case 1:
                        instance = _b.sent();
                        if (instance === null) {
                            return [2 /*return*/, {
                                    field: null,
                                    displayField: null
                                }];
                        }
                        return [4 /*yield*/, this.options];
                    case 2:
                        options = _b.sent();
                        _a = {};
                        return [4 /*yield*/, Promise.resolve().then(function () { return tslib_1.__importStar(require('../components/DisplayField')); }).then(function (mod) { return mod.default; })];
                    case 3: return [2 /*return*/, (_a.displayField = _b.sent(),
                            _a.field = instance.getField(options.fieldName),
                            _a)];
                }
            });
        });
    };
    /**
     * Render DisplayField with foreign field
     */
    ForeignKeyField.prototype.displayRender = function (h, _a) {
        var field = _a.field, displayField = _a.displayField;
        return h(displayField, { props: { field: field } });
    };
    /**
     * Prepare value and list of entries for inputRender
     */
    ForeignKeyField.prototype.prepareInputRender = function (inputProps) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _a, value, options, _b;
            return tslib_1.__generator(this, function (_c) {
                switch (_c.label) {
                    case 0: return [4 /*yield*/, Promise.all([_super.prototype.getValue.call(this), this.options])];
                    case 1:
                        _a = _c.sent(), value = _a[0], options = _a[1];
                        _b = {
                            value: !common_1.isNull(value) ? String(value) : null
                        };
                        return [4 /*yield*/, this.mapInputSelectList(options)];
                    case 2: return [2 /*return*/, (_b.list = _c.sent(),
                            _b.inputProps = inputProps,
                            _b)];
                }
            });
        });
    };
    /**
     * Retrieve and map input select list
     */
    ForeignKeyField.prototype.mapInputSelectList = function (options) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var data;
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.getInputSelectList(options)];
                    case 1:
                        data = _a.sent();
                        return [2 /*return*/, Promise.all(data.map(function (entry) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                                var pk, field, text;
                                return tslib_1.__generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0:
                                            pk = entry.pk;
                                            if (common_1.isNull(pk)) {
                                                console.warn('[vue-service-model] No primary key defined for model', entry.cls.name);
                                            }
                                            field = entry.getField(options.fieldName);
                                            if (!(field instanceof FormatStringField_1.FormatStringField)) return [3 /*break*/, 2];
                                            return [4 /*yield*/, field.valueFormatter()];
                                        case 1:
                                            text = _a.sent();
                                            return [3 /*break*/, 3];
                                        case 2:
                                            console.error('[vue-service-model] Cannot use non string field for ForeignKeyField input. Used field name:', field.name);
                                            text = 'unknown';
                                            _a.label = 3;
                                        case 3: return [2 /*return*/, {
                                                value: String(pk),
                                                text: text
                                            }];
                                    }
                                });
                            }); }))];
                }
            });
        });
    };
    /**
     * Retrieve input select list
     */
    ForeignKeyField.prototype.getInputSelectList = function (options) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, options.model.objects.list()];
            });
        });
    };
    /**
     * Render select input element and options
     */
    ForeignKeyField.prototype.inputRender = function (h, _a) {
        var _this = this;
        var value = _a.value, list = _a.list, inputProps = _a.inputProps;
        var disabled = inputProps.disabled, readonly = inputProps.readonly;
        return h('select', {
            attrs: {
                disabled: disabled,
                readonly: readonly
            },
            on: {
                input: function (event) {
                    var target = event.target;
                    _this.setParseValue(target.value);
                }
            }
        }, list.map(function (entry) { return h('option', {
            attrs: {
                value: entry.value,
                selected: value !== null && value === entry.value
            }
        }, entry.text); }));
    };
    return ForeignKeyField;
}(RenderableField_1.RenderableField));
exports.ForeignKeyField = ForeignKeyField;
