"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RenderableField = void 0;
var tslib_1 = require("tslib");
var Field_1 = require("./Field");
var RenderableField = /** @class */ (function (_super) {
    tslib_1.__extends(RenderableField, _super);
    function RenderableField() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(RenderableField.prototype, "displayComponent", {
        /**
         * Display component to render when displaying value with <display-field/>
         */
        get: function () {
            return Promise.resolve().then(function () { return tslib_1.__importStar(require('../components/BaseDisplayFieldRender')); });
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Async function to prepare before displayRender gets called
     * Can return any data which needs to be resolved for displayRender
     */
    RenderableField.prototype.prepareDisplayRender = function (renderProps) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, this.value];
            });
        });
    };
    /**
     * Simple Vue render function when using default displayComponent when displaying value with <display-field/>
     */
    RenderableField.prototype.displayRender = function (h, renderData) {
        return h('span', renderData);
    };
    Object.defineProperty(RenderableField.prototype, "inputComponent", {
        /**
         * Input component to render when showing input for field with <input-field/>
         */
        get: function () {
            return Promise.resolve().then(function () { return tslib_1.__importStar(require('../components/BaseInputFieldRender')); });
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Async function to prepare before inputRender gets called
     * Can return any data which needs to be resolved for inputRender
     */
    RenderableField.prototype.prepareInputRender = function (inputProps, renderProps) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _a;
            return tslib_1.__generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        _a = {};
                        return [4 /*yield*/, this.value];
                    case 1: return [2 /*return*/, (_a.value = _b.sent(),
                            _a.inputProps = inputProps,
                            _a)];
                }
            });
        });
    };
    /**
     * Simple Vue render function when using default inputComponent for input of field value with <input-field/>
     */
    RenderableField.prototype.inputRender = function (h, renderData) {
        var _this = this;
        var _a = renderData.inputProps, disabled = _a.disabled, readonly = _a.readonly;
        return h('input', {
            attrs: {
                type: 'text',
                value: renderData.value,
                disabled: disabled,
                readonly: readonly
            },
            on: {
                input: function (event) {
                    var target = event.target;
                    _this.setParseValue(target.value);
                }
            }
        });
    };
    return RenderableField;
}(Field_1.Field));
exports.RenderableField = RenderableField;
