"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.configHandler = void 0;
var tslib_1 = require("tslib");
var config_1 = require("../config");
var common_1 = require("../utils/common");
var defaultConfig = {
    useAsyncComputed: false,
    i18n: {
        no: 'No',
        yes: 'Yes'
    },
    events: {
        onSendDetailRequest: function () { },
        onSendListRequest: function () { },
        onSendCreateRequest: function () { },
        onSendUpdateRequest: function () { },
        onSendPartialUpdateRequest: function () { },
        onSendDeleteRequest: function () { },
        onResponseError: function () { }
    }
};
exports.configHandler = {
    defaultConfig: defaultConfig,
    getConfig: function () {
        return common_1.mergeDeep({}, defaultConfig, config_1.getConfig());
    },
    /**
     * Return flag whether asyncComputed package should be used
     */
    useAsyncComputed: function () {
        var _config = this.getConfig();
        return Boolean(_config.useAsyncComputed);
    },
    /**
     * Check whether useAsyncComputed should be true and output warning if not
     */
    checkWarningUseAsyncComputed: function () {
        if (!exports.configHandler.useAsyncComputed()) {
            console.warn('[vue-service-model] asyncComputed has been called, but useAsyncComputed config is false.');
        }
    },
    /**
     * Get translation for given key
     */
    getTranslation: function (key) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _config;
            return tslib_1.__generator(this, function (_a) {
                _config = this.getConfig();
                if (!_config.i18n[key]) {
                    throw new Error('Try to get unknown translation key: ' + key);
                }
                return [2 /*return*/, common_1.promiseEval(_config.i18n[key], null, key)];
            });
        });
    },
    /**
     * Emit event
     */
    emitEvent: function (event, args) {
        var _a;
        var _config = this.getConfig();
        if (!_config.events[event]) {
            throw new Error('Try to emit unknown event: ' + event);
        }
        (_a = _config.events)[event].apply(_a, args);
    }
};
